@@ -1,8 +1,10 @@
-<?php  // $Id: config.php,v 1.36.2.1 2006/05/22 17:54:13 stronk7 Exp $
+<?php  // $Id: config.php,v 1.36.2.3 2006/09/07 20:33:03 skodak Exp $
        // config.php - allows admin to edit all configuration variables
 
     require_once('../config.php');
 
+    $installing = optional_param('installing', 0, PARAM_BOOL);
+
     $focus = '';
 
     if ($site = get_site()) {   // If false then this is a new installation
@@ -46,7 +48,10 @@
                         $value = implode(',',$value);
                     }
                 }
-                unset($conf);
+                if ($name == "locale") {
+                    $value = trim($value);
+                }
+                $conf = new object();
                 $conf->name  = $name;
                 $conf->value = $value;
                 if ($current = get_record('config', 'name', $name)) {
@@ -60,8 +65,16 @@
                     }
                 }
             }
-            redirect('index.php', get_string('changessaved'), 1);
-            exit;
+            if ($installing) {
+                print_header();
+                notify(get_string('changessaved'), 'notifysuccess');
+                print_continue('index.php');
+                exit;
+            } else {
+                // the following redirect was randomly breaking upgrades because it did double redirects,
+                // we must not use it during install/upgrade
+                redirect('index.php', get_string('changessaved'), 1);
+            }
 
         } else {
             foreach ($err as $key => $value) {
@@ -74,9 +87,6 @@
 
     if (empty($config)) {
         $config = $CFG;
-        if (!$config->locale = get_field('config', 'value', 'name', 'locale')) {
-            $config->locale = $CFG->lang;
-        }
     }
 
     $sesskey = !empty($USER->id) ? $USER->sesskey : '';
@@ -143,6 +153,7 @@
 
     }
     echo '<center>';
+    echo '<input type="hidden" name="installing" value="'.$installing.'" />';
     echo '<input type="hidden" name="sesskey" value="'.$sesskey.'" />';
     echo '<input type="submit" value="'.get_string('savechanges').'" />';
     echo '</center>';
