@@ -1,4 +1,4 @@
-# $Id: postgres7.sql,v 1.5.2.2 2005/09/02 04:58:57 mjollnir_ Exp $
+# $Id: postgres7.sql,v 1.8 2005/09/02 05:00:59 mjollnir_ Exp $
 # 
 # Table structure for table blocks
 # 
@@ -23,8 +23,19 @@ CREATE TABLE prefix_block_instance (
   visible int not null default '0',
   configdata text not null default ''
 ) ;
-
 CREATE INDEX prefix_block_instance_pageid_idx ON prefix_block_instance (pageid);
 CREATE INDEX prefix_block_instance_pagetype_idx ON prefix_block_instance (pagetype);
+
+CREATE TABLE prefix_block_pinned ( 
+  id SERIAL8 PRIMARY KEY,
+  blockid INT8 NOT NULL default 0,
+  pagetype varchar(20) NOT NULL default '',
+  position varchar(10) NOT NULL default '',
+  weight INT NOT NULL default 0,
+  visible INT NOT NULL default 0,
+  configdata text NOT NULL default 0
+) ;
       
+CREATE INDEX prefix_block_pinned_pagetype_idx ON prefix_block_pinned (pagetype);
+
 # --------------------------------------------------------
