@@ -1,4 +1,4 @@
-<?php //$Id: lib.php,v 1.38 2006/05/01 06:23:41 toyomoyo Exp $
+<?php //$Id: lib.php,v 1.38.2.2 2006/10/07 16:34:20 gustav_delius Exp $
 
     /**
      * Library of functions and constants for blog
@@ -151,10 +151,10 @@
 
         global $USER, $CFG, $course, $ME;
 
-        $template['body'] = get_formatted_entry_body(stripslashes_safe($blogEntry->summary), $blogEntry->format);
+        $template['body'] = get_formatted_entry_body($blogEntry->summary, $blogEntry->format);
         $template['title'] = '<a name="'. $blogEntry->subject .'"></a>';
         //enclose the title in nolink tags so that moodle formatting doesn't autolink the text
-        $template['title'] .= '<span class="nolink">'. stripslashes_safe($blogEntry->subject);
+        $template['title'] .= '<span class="nolink">'. $blogEntry->subject;
         $template['title'] .= '</span>';
         $template['userid'] = $blogEntry->userid;
         $template['author'] = fullname(get_record('user','id',$blogEntry->userid));
@@ -339,7 +339,7 @@
         if ($format) {
             return format_text($body, $format);
         }
-        return stripslashes_safe($body);
+        return $body;
     }
 
 /// Main filter function
@@ -408,8 +408,8 @@
 
             case 'site':
 
-                if (!isguest() && isloggedin()) {
-
+                if (isloggedin()) {
+					
                     $SQL = 'SELECT '.$requiredfields.' FROM '.$CFG->prefix.'post p, '.$tagtablesql
                             .$CFG->prefix.'user u
                             WHERE p.userid = u.id '.$tagquerysql.'
@@ -469,22 +469,33 @@
 
             case 'group':
 
-                $SQL = 'SELECT '.$requiredfields.' FROM '.$CFG->prefix.'post p, '.$tagtablesql
-                        .$CFG->prefix.'groups_members m, '.$CFG->prefix.'user u
-                        WHERE p.userid = m.userid '.$tagquerysql.'
-                        AND u.id = p.userid
-                        AND m.groupid = '.$filterselect.'
-                        AND (p.publishstate = \'site\' OR p.publishstate = \'public\' OR p.userid = '.$USER->id.')';
+				$SQL = 'SELECT '.$requiredfields.' FROM '.$CFG->prefix.'post p, '.$tagtablesql
+	                    .$CFG->prefix.'groups_members m, '.$CFG->prefix.'user u
+	                    WHERE p.userid = m.userid '.$tagquerysql.'
+	                    AND u.id = p.userid
+	                    AND m.groupid = '.$filterselect.'
+	                    AND (p.publishstate = \'site\' OR p.publishstate = \'public\' OR p.userid = '.$USER->id.')';
 
             break;
 
             case 'user':
-
-                $SQL = 'SELECT '.$requiredfields.' FROM '.$CFG->prefix.'post p, '.$tagtablesql
-                        .$CFG->prefix.'user u
-                        WHERE p.userid = u.id '.$tagquerysql.'
-                        AND u.id = '.$filterselect.'
-                        AND (p.publishstate = \'site\' OR p.publishstate = \'public\' OR p.userid = '.$USER->id.')';
+				
+				if (isloggedin()) {
+				  
+	                $SQL = 'SELECT '.$requiredfields.' FROM '.$CFG->prefix.'post p, '.$tagtablesql
+	                        .$CFG->prefix.'user u
+	                        WHERE p.userid = u.id '.$tagquerysql.'
+	                        AND u.id = '.$filterselect.'
+	                        AND (p.publishstate = \'site\' OR p.publishstate = \'public\' OR p.userid = '.$USER->id.')';
+	            } else {
+	                
+					$SQL = 'SELECT '.$requiredfields.' FROM '.$CFG->prefix.'post p, '.$tagtablesql
+	                        .$CFG->prefix.'user u
+	                        WHERE p.userid = u.id '.$tagquerysql.'
+	                        AND u.id = '.$filterselect.'
+	                        AND p.publishstate = \'public\'';	              
+	              
+	            }
 
             break;
 
