@@ -1,4 +1,4 @@
-<?PHP // $Id: moodle.php,v 1.29.2.4 2006/06/08 06:18:06 vyshane Exp $
+<?PHP // $Id: moodle.php,v 1.29.2.9 2006/09/07 05:50:06 skodak Exp $
       // moodle.php - created with Moodle 1.5 UNSTABLE DEVELOPMENT (2005010100)
 
 $string['action'] = 'Action';
@@ -53,6 +53,7 @@ $string['adminhelpedituser'] = 'Browse the list of user accounts and edit any of
 $string['adminhelpenrolments'] = 'Choose internal or external ways to control enrolments';
 $string['adminhelpenvironment'] = 'Check how your server suits current and future installation requirements';
 $string['adminhelpfailurelogs'] = 'Browse logs of failed logins';
+$string['adminhelphealthcenter'] = 'Automatic detection of site problems';
 $string['adminhelplanguage'] = 'For checking and editing the current language pack';
 $string['adminhelplogs'] = 'Browse logs of all activity on this site';
 $string['adminhelpmanageblocks'] = 'Manage installed blocks and their settings';
@@ -394,6 +395,9 @@ line at the top of your web browser window.
 If you need help, please contact the site administrator,
 $a->admin';
 $string['emailconfirmationsubject'] = '$a: account confirmation';
+$string['emailpasswordconfirmmaybesent'] = '   <p>If you supplied correct username or address an email should have been sent to you.</p>
+   <p>It contains easy instructions to confirm and complete this password change.
+If you continue to have difficulty, please contact the site administrator.</p>';
 $string['emailconfirmsent'] = '   <p>An email should have been sent to your address at <b>$a</b></p>
    <p>It contains easy instructions to complete your registration.</p>
    <p>If you continue to have difficulty, contact the site administrator.</p>';
@@ -489,7 +493,7 @@ $string['existingstudents'] = 'Enrolled students';
 $string['existingteachers'] = 'Existing teachers';
 $string['explanation'] = 'Explanation';
 $string['expirynotify'] = 'Enrolment expiry notification';
-$string['expirynotifyemail'] = 'The following students in this course are expiring after exact $a->threshold days:
+$string['expirynotifyemail'] = 'The following students in this course are expiring after exactly $a->threshold days:
 
 $a->current
 
@@ -503,11 +507,11 @@ You may go to the following page to extend their enrolment period:
 $a->extendurl
 ';
 $string['expirynotifystudents'] = 'Notify students';
-$string['expirynotifystudentsemail'] = 'Dear student:
+$string['expirynotifystudentsemail'] = 'Dear $a->studentstr:
 
-This is a notification that your enrolment for course $a->course will be expired in $a->threshold days.
+This is a notification that your enrolment in the course $a->course will expire in $a->threshold days.
 
-Please contact your tutor for any further enqiries.
+Please contact your $a->teacherstr for any further enquiries.
 ';
 $string['expirythreshold'] = 'Threshold';
 $string['extendenrol'] = 'Extend enrolment';
@@ -550,10 +554,12 @@ $string['formatweeks'] = 'Weekly format';
 $string['formatweekscss'] = 'Weekly format - CSS/No tables';
 $string['formatwiki'] = 'Wiki-like format';
 $string['from'] = 'From';
+$string['frontpagecategorycombo'] = 'Combo list';
 $string['frontpagecategorynames'] = 'List of categories';
 $string['frontpagecourselist'] = 'List of courses';
 $string['frontpagedescription'] = 'Front Page Description';
 $string['frontpageformat'] = 'Front page format';
+$string['frontpageformatloggedin'] = 'Front page format when logged in';
 $string['frontpagenews'] = 'News items';
 $string['frontpagetopiconly'] = 'Topic section';
 $string['fulllistofcourses'] = 'All courses';
@@ -751,6 +757,7 @@ $string['makeafolder'] = 'Make a folder';
 $string['makeeditable'] = 'If you make \'$a\' editable by the web server process (eg apache) then you could edit this file directly from this page';
 $string['manageblocks'] = 'Blocks';
 $string['managedatabase'] = 'Database';
+$string['managecourses'] = 'Manage courses';
 $string['managefilters'] = 'Filters';
 $string['managemeta'] = 'Is this a meta course?';
 $string['managemetaexplan'] = '(This means that enrolments are inherited from other courses)';
