@@ -1,9 +1,9 @@
-<?php // $Id: migrate2utf8.php,v 1.16.2.2 2006/06/08 02:45:51 toyomoyo Exp $
+<?php // $Id: migrate2utf8.php,v 1.16.2.5 2006/08/10 02:41:19 toyomoyo Exp $
 // This is a one-shot function that converts an entire table on row basis.
 
-function migrate2utf8_user($fields, $crash, $debug, $maxrecords) {
+function migrate2utf8_user($fields, $crash, $debug, $maxrecords, $done, $tablestoconvert) {
 
-    global $CFG, $db, $processedrecords;
+    global $CFG, $db, $processedrecords, $globallang;
 
     // convert all columns to blobs
     foreach ($fields as $field) {
@@ -74,7 +74,11 @@ function migrate2utf8_user($fields, $crash, $debug, $maxrecords) {
                 update_record('config',$migrationconfig);
                 
                 // this is the only encoding we need for this table
-                $fromenc = get_original_encoding('','',$record->lang);
+                if ($globallang) {
+        			$fromenc = $globallang;
+        		} else {
+                	$fromenc = get_original_encoding($CFG->lang,'',$record->lang);
+                }
 
                 if (($fromenc != 'utf-8') && ($fromenc != 'UTF-8')) {
                     foreach ($fields as $field) {
@@ -120,9 +124,10 @@ function migrate2utf8_user($fields, $crash, $debug, $maxrecords) {
 
                 $processedrecords++;
                 //print some output once in a while
-                if (($processedrecords) % 5000 == 0) {
-                    echo 'Processing...'.$dbtablename.'...'.$fieldname.'...'.$record->id;
-                }
+                
+                if (($processedrecords) % 1000 == 0) {
+            		print_progress($done, $tablestoconvert, 5, 1, 'Processing: user');
+            	}
             }
         }
     }
