@@ -1,4 +1,4 @@
-<?PHP 
+<?php 
 
 function chat_upgrade($oldversion) {
 // This function does anything necessary to upgrade
