@@ -1,4 +1,4 @@
-<?php  // $Id: lib.php,v 1.70.2.4 2006/06/06 10:15:49 skodak Exp $
+<?php  // $Id: lib.php,v 1.70.2.5 2006/07/03 21:07:41 skodak Exp $
 ///////////////////////////////////////////////////////////////////////////
 //                                                                       //
 // NOTICE OF COPYRIGHT                                                   //
@@ -1175,8 +1175,8 @@ function data_print_comment($data, $comment, $page=0) {
     echo '</div></td></tr>';
 
     echo '<tr><td class="left side">';
-    if ($group = user_group($data->course, $comment->userid)) {
-        print_group_picture($group, $data->course, false, false, true);
+    if ($groups = user_group($data->course, $comment->userid)) {
+        print_group_picture($groups, $data->course, false, false, true);
     } else {
         echo '&nbsp;';
     }
