@@ -1,4 +1,4 @@
-<?php // $Id: rate.php,v 1.14.2.1 2005/11/15 21:47:18 skodak Exp $
+<?php // $Id: rate.php,v 1.16.4.1 2006/10/05 03:14:20 vyshane Exp $
 
 //  Collect ratings, store them, then return to where we came from
 
@@ -10,7 +10,7 @@
         error("Guests are not allowed to rate posts.", $_SERVER["HTTP_REFERER"]);
     }
 
-    require_variable($id);  // The course these ratings are part of
+    $id = required_param('id',PARAM_INT);  // The course these ratings are part of
 
     if (! $course = get_record("course", "id", $id)) {
         error("Course ID was incorrect");
@@ -39,7 +39,10 @@
             $postid = (int)$postid;
             $lastpostid = $postid;
 
-            if ($oldrating = get_record("forum_ratings", "userid", $USER->id, "post", $postid)) {
+            if ($rating == FORUM_UNSET_POST_RATING) {
+                delete_records('forum_ratings', 'post', $postid, 'userid', $USER->id);
+
+            } else if ($oldrating = get_record("forum_ratings", "userid", $USER->id, "post", $postid)) {
                 if ($rating != $oldrating->rating) {
                     $oldrating->rating = $rating;
                     $oldrating->time = time();
@@ -47,7 +50,7 @@
                         error("Could not update an old rating ($postid = $rating)");
                     }
                 }
-            } else if ($rating) {
+            } else {
                 unset($newrating);
                 $newrating->userid = $USER->id;
                 $newrating->time = time();
@@ -73,4 +76,4 @@
         error("This page was not accessed correctly");
     }
 
-?>
+?>
\ No newline at end of file
