@@ -1,4 +1,4 @@
-<?php //$Id: restorelib.php,v 1.42.2.3 2006/06/06 17:23:42 tjhunt Exp $
+<?php //$Id: restorelib.php,v 1.42.2.4 2006/09/25 04:01:53 vyshane Exp $
     //This php script contains all the stuff to backup/restore
     //forum mods
 
@@ -263,7 +263,7 @@
             }
 
             //We have to recode the groupid field
-            $group = backup_getid($restore->backup_unique_code,"group",$discussion->groupid);
+            $group = backup_getid($restore->backup_unique_code, 'groups', $discussion->groupid);
             if ($group) {
                 $discussion->groupid = $group->new_id;
             }
