@@ -1,25 +1,22 @@
-<?php  // $Id: editcategories.php,v 1.21 2005/03/30 11:14:19 stronk7 Exp $
+<?php  // $Id: editcategories.php,v 1.23.2.1 2006/08/10 15:30:49 skodak Exp $
 
 /// This page allows to edit entries categories for a particular instance of glossary
 
     require_once("../../config.php");
     require_once("lib.php");
 
-    require_variable($id);    // Course Module ID, or
-    optional_variable($usedynalink);  // category ID
-    optional_variable($confirm);  // confirm the action
+    $id = required_param('id', PARAM_INT);                       // Course Module ID, or
+    $usedynalink = optional_param('usedynalink', 0, PARAM_INT);  // category ID
+    $confirm     = optional_param('confirm', 0, PARAM_INT);      // confirm the action
+    $name        = optional_param('name', '', PARAM_CLEAN);  // confirm the name
 
-    optional_variable($name);  // confirm the name
-
-    $name = clean_text($name);
-
-    $action = optional_param('action'); // what to do
-    $hook   = optional_param('hook',0); // category ID
-    $mode   = optional_param('mode');   // cat
+    $action = optional_param('action', '', PARAM_ALPHA ); // what to do
+    $hook   = optional_param('hook', '', PARAM_ALPHANUM); // category ID
+    $mode   = optional_param('mode', '', PARAM_ALPHA);   // cat
 
     $action = strtolower($action);
 
-    if (! $cm = get_record("course_modules", "id", $id)) {
+    if (! $cm = get_coursemodule_from_id('glossary', $id)) {
         error("Course Module ID was incorrect");
     }
 
