@@ -10,9 +10,9 @@ function lesson_upgrade($oldversion) {
 
        delete_records("log_display", "module", "lesson");
 
-       modify_database ("", "INSERT INTO prefix_log_display VALUES ('lesson', 'start', 'lesson', 'name');");
-       modify_database ("", "INSERT INTO prefix_log_display VALUES ('lesson', 'end', 'lesson', 'name');");
-       modify_database ("", "INSERT INTO prefix_log_display VALUES ('lesson', 'view', 'lesson_pages', 'title');");
+       modify_database ("", "INSERT INTO prefix_log_display (module, action, mtable, field) VALUES ('lesson', 'start', 'lesson', 'name');");
+       modify_database ("", "INSERT INTO prefix_log_display (module, action, mtable, field) VALUES ('lesson', 'end', 'lesson', 'name');");
+       modify_database ("", "INSERT INTO prefix_log_display (module, action, mtable, field) VALUES ('lesson', 'view', 'lesson_pages', 'title');");
 
     }
 
@@ -39,48 +39,76 @@ function lesson_upgrade($oldversion) {
     if ($oldversion < 2004032700) {
         table_column("lesson_answers", "", "flags", "INTEGER", "4", "UNSIGNED", "0", "NOT NULL", "grade");
     }
- // CDC-FLAG
+    
+    if ($oldversion < 2004060501) {
+        // matching questions need 2 records for responses and the
+        // 2 records must appear before the old ones.  So, delete the old ones,
+        // create the 2 needed, then re-insert the old ones for each matching question.
+        if ($matchingquestions = get_records('lesson_pages', 'qtype', 5)) {  // get our matching questions
+            foreach ($matchingquestions as $matchingquestion) {
+                if ($answers = get_records('lesson_answers', 'pageid', $matchingquestion->id)) { // get answers
+                    if (delete_records('lesson_answers',  'pageid', $matchingquestion->id)) {  // delete them
+                        $time = time();
+                        // make our 2 response answers
+                        $newanswer->lessonid = $matchingquestion->lessonid;
+                        $newanswer->pageid = $matchingquestion->id;
+                        $newanswer->timecreated = $time;
+                        $newanswer->timemodified = 0;
+                        insert_record('lesson_answers', $newanswer);
+                        insert_record('lesson_answers', $newanswer);
+                        // insert our old answers
+                        foreach ($answers as $answer) {
+                            $answer->timecreated = $time;
+                            $answer->timemodified = 0;
+                            insert_record('lesson_answers', (object) array_map('addslashes', (array)$answer));
+                        }
+                    }
+                }
+            }
+        }
+    }
+    
     if ($oldversion < 2004072100) {
         execute_sql(" create table ".$CFG->prefix."lesson_high_scores
                     ( id serial8 primary key,
-                      lessonid int8 not null,
-                      userid int8 not null,
-                      gradeid int8 not null,
-                      nickname varchar(5) not null
+                      lessonid int8 not null default '0',
+                      userid int8 not null default '0',
+                      gradeid int8 not null default '0',
+                      nickname varchar(5) not null default ''
                     )");
 
         execute_sql(" create table ".$CFG->prefix."lesson_essay
                     ( id serial8 primary key,
-                      lessonid int8 not null,
-                      userid int8 not null,
-                      pageid int8 not null,
-                      answerid int8 not null,
-                      try int8 not null,
-                      answer text not null,
+                      lessonid int8 not null default '0',
+                      userid int8 not null default '0',
+                      pageid int8 not null default '0',
+                      answerid int8 not null default '0',
+                      try int8 not null default '0',
+                      answer text not null default '',
                       graded int4 not null default 0,
                       score int8 not null default 0,
-                      response text not null,
+                      response text not null default '',
                       sent int4 not null default 0,
-                      timesubmitted int8 not null
+                      timesubmitted int8 not null default '0'
                     )");
 
         execute_sql(" create table ".$CFG->prefix."lesson_branch
                     ( id serial8 primary key,
-                      lessonid int8 not null,
-                      userid int8 not null,
-                      pageid int8 not null,
-                      retry int8 not null,
-                      flag  int4 not null,
-                      timeseen int8 not null
+                      lessonid int8 not null default '0',
+                      userid int8 not null default '0',
+                      pageid int8 not null default '0',
+                      retry int8 not null default '0',
+                      flag  int4 not null default '0',
+                      timeseen int8 not null default '0'
                     )");
 
         
         execute_sql(" create table ".$CFG->prefix."lesson_timer
                     ( id serial8 primary key,
-                      lessonid int8 not null,
-                    userid int8 not null,
-                    starttime int8 not null,
-                      lessontime int8 not null
+                      lessonid int8 not null default '0',
+                    userid int8 not null default '0',
+                    starttime int8 not null default '0',
+                      lessontime int8 not nul default '0'l
                     )");
 
     
@@ -174,7 +202,7 @@ function lesson_upgrade($oldversion) {
           maxhighscores int8 NOT NULL default '0'
         )");
     }
-    // CDC-FLAG end    
+    
     if ($oldversion < 2004100400) {
         //execute_sql(" ALTER TABLE `{$CFG->prefix}lesson_attempts` ADD `useranswer` text NOT NULL AFTER correct");
         table_column('lesson_attempts', '', 'useranswer', 'text', '', '', '', 'NOT NULL', 'correct');
@@ -215,7 +243,7 @@ function lesson_upgrade($oldversion) {
     if ($oldversion < 2005060900) {
         table_column('lesson_grades', 'grade', 'grade', 'real', '', 'unsigned', '0', 'not null');
     }
-
+    
     if ($oldversion < 2005060901) { // Mass cleanup of bad postgres upgrade scripts
         modify_database('','ALTER TABLE prefix_lesson ALTER bgcolor SET NOT NULL');
         modify_database('','ALTER TABLE prefix_lesson ALTER custom SET NOT NULL');
@@ -225,6 +253,7 @@ function lesson_upgrade($oldversion) {
         table_column('lesson','maxhighscores','maxhighscores','integer','16');
         modify_database('','ALTER TABLE prefix_lesson ALTER displayleft SET NOT NULL');
         table_column('lesson','','minquestions','integer','8');
+        notify('The above error can be ignored if the column already exists, its possible that it was cleaned up already before running this upgrade');
         table_column('lesson','maxtime','maxtime','integer','16');
         modify_database('','ALTER TABLE prefix_lesson ALTER ongoing SET NOT NULL');
         modify_database('','ALTER TABLE prefix_lesson ALTER password SET NOT NULL');
@@ -246,6 +275,84 @@ function lesson_upgrade($oldversion) {
         table_column('lesson_pages','qtype','qtype','integer','8');
     }
 
+    if ($oldversion < 2005061500) {
+        table_column('lesson', '', 'mediafile', 'varchar', '255', '', '', 'not null', 'tree');
+    }
+    
+    if ($oldversion < 2005063000) {
+        table_column('lesson', '', 'dependency', 'INT', '8', 'unsigned', '0', 'not null', 'usepassword');
+        table_column('lesson', '', 'conditions', 'text', '', '', '', 'not null', 'dependency');
+    }
+    
+    if ($oldversion < 2005101900) {
+        table_column('lesson', '', 'progressbar', 'INT', '3', 'unsigned', '0', 'not null', 'displayleft');
+        table_column('lesson', '', 'displayleftif', 'INT', '3', 'unsigned', '0', 'not null', 'displayleft');
+    }
+    
+    if ($oldversion < 2005102800) {
+        table_column('lesson', '', 'mediaclose', 'INT', '3', 'unsigned', '0', 'not null', 'mediafile');
+        table_column('lesson', '', 'mediaheight', 'INT', '10', 'unsigned', '100', 'not null', 'mediafile');
+        table_column('lesson', '', 'mediawidth', 'INT', '10', 'unsigned', '650', 'not null', 'mediafile');
+    }
+
+    if ($oldversion < 2005110200) {
+        table_column('lesson', '', 'activitylink', 'INT', '10', 'unsigned', '0', 'not null', 'tree');
+    }
+    
+    if ($oldversion < 2006031900) {
+        execute_sql('ALTER TABLE  '. $CFG->prefix . 'lesson DROP COLUMN tree');
+        execute_sql('ALTER TABLE  '. $CFG->prefix . 'lesson_default DROP COLUMN tree');
+    }
+    
+    if ($oldversion < 2006050100) {   
+        table_column('lesson_default', '', 'conditions', 'text', '', '', '', 'not null', 'password');
+        table_column('lesson_default', '', 'progressbar', 'tinyint', '3', 'unsigned', '0', 'not null', 'displayleft');
+        table_column('lesson_default', '', 'displayleftif', 'int', '3', 'unsigned', '0', 'not null', 'displayleft'); 
+        table_column('lesson_default', '', 'mediaclose', 'tinyint', '3', 'unsigned', '0', 'not null', 'retake');
+        table_column('lesson_default', '', 'mediaheight', 'int', '10', 'unsigned', '100', 'not null', 'retake');
+        table_column('lesson_default', '', 'mediawidth', 'int', '10', 'unsigned', '650', 'not null', 'retake');
+    }
+
+    if ($oldversion < 2006050101) {
+        // drop the unused table
+        execute_sql('DROP TABLE '.$CFG->prefix.'lesson_essay', false);
+
+        // properly set the correct default values
+        table_column('lesson', 'activitylink', 'activitylink', 'integer', '8', '', '0');
+        table_column('lesson', 'dependency', 'dependency', 'integer', '8', '', '0');
+
+        modify_database('', 'ALTER TABLE prefix_lesson_timer
+            ALTER COLUMN lessontime SET DEFAULT 0');
+        modify_database('', 'ALTER TABLE prefix_lesson_timer
+            ALTER COLUMN lessonid SET DEFAULT 0');
+        modify_database('', 'ALTER TABLE prefix_lesson_timer
+            ALTER COLUMN userid SET DEFAULT 0');
+        modify_database('', 'ALTER TABLE prefix_lesson_timer
+            ALTER COLUMN starttime SET DEFAULT 0');
+
+        modify_database('', 'ALTER TABLE prefix_lesson_branch
+            ALTER COLUMN lessonid SET DEFAULT 0');
+        modify_database('', 'ALTER TABLE prefix_lesson_branch
+            ALTER COLUMN timeseen SET DEFAULT 0');
+        modify_database('', 'ALTER TABLE prefix_lesson_branch
+            ALTER COLUMN userid SET DEFAULT 0');
+        modify_database('', 'ALTER TABLE prefix_lesson_branch
+            ALTER COLUMN retry SET DEFAULT 0');
+        modify_database('', 'ALTER TABLE prefix_lesson_branch
+            ALTER COLUMN pageid SET DEFAULT 0');
+        modify_database('', 'ALTER TABLE prefix_lesson_branch
+            ALTER COLUMN flag SET DEFAULT 0');
+
+        modify_database('', 'ALTER TABLE prefix_lesson_high_scores
+            ALTER COLUMN nickname SET DEFAULT \'\'');
+        modify_database('', 'ALTER TABLE prefix_lesson_high_scores
+            ALTER COLUMN lessonid SET DEFAULT 0');
+        modify_database('', 'ALTER TABLE prefix_lesson_high_scores
+            ALTER COLUMN gradeid SET DEFAULT 0');
+        modify_database('', 'ALTER TABLE prefix_lesson_high_scores
+            ALTER COLUMN userid SET DEFAULT 0');
+    }
+
    return true;
 }
 
