@@ -1,7 +1,8 @@
-<?PHP // $Id: quizfile.php,v 1.11 2005/03/07 11:32:00 moodler Exp $
+<?PHP // $Id: quizfile.php,v 1.14 2006/03/01 07:02:58 gustav_delius Exp $
       // This function fetches files from the data directory
       // Syntax:   quizfile.php/quiz id/question id/dir/.../dir/filename.ext
       // It is supposed to be used by the quiz module only
+      // I believe this is obsolete, everything should be using moodle/file.php GWD
 
     require_once('../../config.php');
     require_once($CFG->libdir.'/filelib.php');
@@ -29,11 +30,11 @@
     $questionid   = (int)array_shift($args);
     $relativepath = implode ('/', $args);
 
-    if (!($question = get_record('quiz_questions', 'id', $questionid))) {
+    if (!($question = get_record('question', 'id', $questionid))) {
         error('No valid arguments supplied');
     }
 
-    if (!($questioncategory = get_record('quiz_categories', 'id', $question->category))) {
+    if (!($questioncategory = get_record('question_categories', 'id', $question->category))) {
         error('No valid arguments supplied');
     }
 
@@ -84,7 +85,7 @@
     }
 
     // Have the question check whether it uses this file or not
-    if (!$QUIZ_QTYPES[$question->qtype]->uses_quizfile($question,
+    if (!$QTYPES[$question->qtype]->uses_quizfile($question,
                                                        $relativepath)) {
         error("The specified file path is not on the specified question");
     }
