@@ -33,6 +33,6 @@ CREATE INDEX prefix_resource_course_idx ON prefix_resource (course);
 # Dumping data for table `log_display`
 #
 
-INSERT INTO prefix_log_display VALUES ('resource', 'view', 'resource', 'name');
-INSERT INTO prefix_log_display VALUES ('resource', 'update', 'resource', 'name');
-INSERT INTO prefix_log_display VALUES ('resource', 'add', 'resource', 'name');
+INSERT INTO prefix_log_display (module, action, mtable, field) VALUES ('resource', 'view', 'resource', 'name');
+INSERT INTO prefix_log_display (module, action, mtable, field) VALUES ('resource', 'update', 'resource', 'name');
+INSERT INTO prefix_log_display (module, action, mtable, field) VALUES ('resource', 'add', 'resource', 'name');
