@@ -1,4 +1,4 @@
-<?PHP //$Id: restorelib.php,v 1.8.2.1 2004/10/01 11:31:12 stronk7 Exp $
+<?php //$Id: restorelib.php,v 1.23 2006/04/11 16:19:17 stronk7 Exp $
     //This php script contains all the stuff to backup/restore
     //resource mods
 
@@ -82,21 +82,24 @@
             $newid = insert_record ("resource",$resource);
 
             //Do some output     
-            echo "<ul><li>".get_string("modulename","resource")." \"".$resource->name."\"<br>";
+            if (!defined('RESTORE_SILENTLY')) {
+                echo "<li>".get_string("modulename","resource")." \"".format_string(stripslashes($resource->name),true)."\"</li>";
+            }
             backup_flush(300);
 
             if ($newid) {
                 //We have the newid, update backup_ids
                 backup_putid($restore->backup_unique_code,$mod->modtype,
                              $mod->id, $newid);
+
+                // restore any associated files...
+                if ($resource->type == 'file' || $resource->type == 'directory' || $resource->type == 'ims') {
+                    resource_restore_files($mod->id,$newid,$resource,$restore);
+                }
    
             } else {
                 $status = false;
             }
-
-            //Finalize ul        
-            echo "</ul>";
-
         } else {
             $status = false;
         }
@@ -173,194 +176,92 @@
     //working in the backup/restore process. It's called from restore_decode_content_links()
     //function in restore process
     function resource_decode_content_links_caller($restore) {
+        global $CFG;
+        $status = true;
+
+        if ($resources = get_records_sql ("SELECT r.id, r.alltext, r.summary, r.reference
+                                   FROM {$CFG->prefix}resource r
+                                   WHERE r.course = $restore->course_id")) {
+
+            $i = 0;   //Counter to send some output to the browser to avoid timeouts
+            foreach ($resources as $resource) {
+                //Increment counter
+                $i++;
+                $content1 = $resource->alltext;
+                $content2 = $resource->summary;
+                $content3 = $resource->reference;
+                $result1 = restore_decode_content_links_worker($content1,$restore);
+                $result2 = restore_decode_content_links_worker($content2,$restore);
+                $result3 = restore_decode_content_links_worker($content3,$restore);
+
+                if ($result1 != $content1 || $result2 != $content2 ||  $result3 != $content3) {
+                    //Update record
+                    $resource->alltext = addslashes($result1);
+                    $resource->summary = addslashes($result2);
+                    $resource->reference = addslashes($result3);
+                    $status = update_record("resource",$resource);
+                    if ($CFG->debug>7) {
+                        if (!defined('RESTORE_SILENTLY')) {
+                            echo '<br /><hr />'.s($content1).'<br />changed to<br />'.s($result1).'<hr /><br />';
+                            echo '<br /><hr />'.s($content2).'<br />changed to<br />'.s($result2).'<hr /><br />';
+                            echo '<br /><hr />'.s($content3).'<br />changed to<br />'.s($result3).'<hr /><br />';
+                        }
+                    }
+                }
+                //Do some output
+                if (($i+1) % 5 == 0) {
+                    if (!defined('RESTORE_SILENTLY')) {
+                        echo ".";
+                        if (($i+1) % 100 == 0) {
+                            echo "<br />";
+                        }
+                    }
+                    backup_flush(300);
+                }
+            }
+        }
+        return $status;
+    }
+
+    //This function converts texts in FORMAT_WIKI to FORMAT_MARKDOWN for
+    //some texts in the module
+    function resource_restore_wiki2markdown ($restore) {
 
         global $CFG;
 
         $status = true;
 
-        echo "<ul>";
-
-        //ASSIGNMENT: Decode every ASSIGNMENT (description) in the coure
-
-        //Check we are restoring assignments
-        if ($restore->mods['assignment']->restore == 1) {
-            echo "<li>".get_string("from")." ".get_string("modulenameplural","assignment");
-            //Get all course assignments
-            if ($assignments = get_records_sql ("SELECT a.id, a.description
-                                       FROM {$CFG->prefix}assignment a
-                                       WHERE a.course = $restore->course_id")) {
-                //Iterate over each assignment->description
-                $i = 0;   //Counter to send some output to the browser to avoid timeouts
-                foreach ($assignments as $assignment) {
-                    //Increment counter
-                    $i++;
-                    $content = $assignment->description;
-                    $result = resource_decode_content_links($content,$restore);
-                    if ($result != $content) {
-                        //Update record
-                        $assignment->description = addslashes($result);
-                        $status = update_record("assignment",$assignment);
-                        if ($CFG->debug>7) {
-                            echo "<br><hr>".$content."<br>changed to</br>".$result."<hr><br>";
-                        }
-                    }
-                    //Do some output
-                    if (($i+1) % 5 == 0) {
+        //Convert resource->alltext
+        if ($records = get_records_sql ("SELECT r.id, r.alltext, r.options
+                                         FROM {$CFG->prefix}resource r,
+                                              {$CFG->prefix}backup_ids b
+                                         WHERE r.course = $restore->course_id AND
+                                               options = ".FORMAT_WIKI. " AND
+                                               b.backup_code = $restore->backup_unique_code AND
+                                               b.table_name = 'resource' AND
+                                               b.new_id = r.id")) {
+            foreach ($records as $record) {
+                //Rebuild wiki links
+                $record->alltext = restore_decode_wiki_content($record->alltext, $restore);
+                //Convert to Markdown
+                $wtm = new WikiToMarkdown();
+                $record->alltext = $wtm->convert($record->alltext, $restore->course_id);
+                $record->options = FORMAT_MARKDOWN;
+                $status = update_record('resource', addslashes_object($record));
+                //Do some output
+                $i++;
+                if (($i+1) % 1 == 0) {
+                    if (!defined('RESTORE_SILENTLY')) {
                         echo ".";
-                        if (($i+1) % 100 == 0) {
-                            echo "<br>";
+                        if (($i+1) % 20 == 0) {
+                            echo "<br />";
                         }
-                        backup_flush(300);
                     }
+                    backup_flush(300);
                 }
             }
+
         }
- 
-        //FORUM: Decode every POST (message) in the coure
-
-        //Check we are restoring forums
-        if ($restore->mods['forum']->restore == 1) {
-            echo "<li>".get_string("from")." ".get_string("modulenameplural","forum");
-            //Get all course posts
-            if ($posts = get_records_sql ("SELECT p.id, p.message
-                                       FROM {$CFG->prefix}forum_posts p,
-                                            {$CFG->prefix}forum_discussions d
-                                       WHERE d.course = $restore->course_id AND
-                                             p.discussion = d.id")) {
-                //Iterate over each post->message
-                $i = 0;   //Counter to send some output to the browser to avoid timeouts
-                foreach ($posts as $post) {
-                    //Increment counter
-                    $i++;
-                    $content = $post->message;
-                    $result = resource_decode_content_links($content,$restore);
-                    if ($result != $content) {
-                        //Update record
-                        $post->message = addslashes($result);
-                        $status = update_record("forum_posts",$post);
-                        if ($CFG->debug>7) {
-                            echo "<br><hr>".$content."<br>changed to</br>".$result."<hr><br>";
-                        }
-                    }
-                    //Do some output
-                    if (($i+1) % 5 == 0) {
-                        echo ".";
-                        if (($i+1) % 100 == 0) {
-                            echo "<br>";
-                        }
-                        backup_flush(300);
-                    }
-                }
-            }
-        }
-
-        //FORUM: Decode every FORUM (intro) in the coure
-
-        //Check we are restoring forums
-        if ($restore->mods['forum']->restore == 1) {
-            //Get all course forums
-            if ($forums = get_records_sql ("SELECT f.id, f.intro
-                                       FROM {$CFG->prefix}forum f
-                                       WHERE f.course = $restore->course_id")) {
-                //Iterate over each forum->intro
-                $i = 0;   //Counter to send some output to the browser to avoid timeouts
-                foreach ($forums as $forum) {
-                    //Increment counter
-                    $i++;
-                    $content = $forum->intro;
-                    $result = resource_decode_content_links($content,$restore);
-                    if ($result != $content) {
-                        //Update record
-                        $forum->intro = addslashes($result);
-                        $status = update_record("forum",$forum);
-                        if ($CFG->debug>7) {
-                            echo "<br><hr>".$content."<br>changed to</br>".$result."<hr><br>";
-                        }
-                    }
-                    //Do some output
-                    if (($i+1) % 5 == 0) {
-                        echo ".";
-                        if (($i+1) % 100 == 0) {
-                            echo "<br>";
-                        }
-                        backup_flush(300);
-                    }
-                }
-            }
-        }
-
-        //RESOURCE: Decode every RESOURCE (alltext) in the coure
-
-        //Check we are restoring resources
-        if ($restore->mods['resource']->restore == 1) {
-            echo "<li>".get_string("from")." ".get_string("modulenameplural","resource");
-            //Get all course resources
-            if ($resources = get_records_sql ("SELECT r.id, r.alltext
-                                       FROM {$CFG->prefix}resource r
-                                       WHERE r.course = $restore->course_id")) {
-                //Iterate over each resource->alltext
-                $i = 0;   //Counter to send some output to the browser to avoid timeouts
-                foreach ($resources as $resource) {
-                    //Increment counter
-                    $i++;
-                    $content = $resource->alltext;
-                    $result = resource_decode_content_links($content,$restore);
-                    if ($result != $content) {
-                        //Update record
-                        $resource->alltext = addslashes($result);
-                        $status = update_record("resource",$resource);
-                        if ($CFG->debug>7) {
-                            echo "<br><hr>".$content."<br>changed to</br>".$result."<hr><br>";
-                        }
-                    }
-                    //Do some output
-                    if (($i+1) % 5 == 0) {
-                        echo ".";
-                        if (($i+1) % 100 == 0) {
-                            echo "<br>";
-                        }
-                        backup_flush(300);
-                    }
-                }
-            }
-        }
-
-        //RESOURCE: Decode every RESOURCE (summary) in the coure
-
-        //Check we are restoring resources
-        if ($restore->mods['resource']->restore == 1) {
-            //Get all course resources
-            if ($resources = get_records_sql ("SELECT r.id, r.summary
-                                       FROM {$CFG->prefix}resource r
-                                       WHERE r.course = $restore->course_id")) {
-                //Iterate over each resource->summary
-                $i = 0;   //Counter to send some output to the browser to avoid timeouts
-                foreach ($resources as $resource) {
-                    //Increment counter
-                    $i++;
-                    $content = $resource->summary;
-                    $result = resource_decode_content_links($content,$restore);
-                    if ($result != $content) {
-                        //Update record
-                        $resource->summary = addslashes($result);
-                        $status = update_record("resource",$resource);
-                        if ($CFG->debug>7) {
-                            echo "<br><hr>".$content."<br>changed to</br>".$result."<hr><br>";
-                        }
-                    }
-                    //Do some output
-                    if (($i+1) % 5 == 0) {
-                        echo ".";
-                        if (($i+1) % 100 == 0) {
-                            echo "<br>";
-                        }
-                        backup_flush(300);
-                    }
-                }
-            }
-        }
-
-        echo "</ul>";
         return $status;
     }
 
@@ -411,7 +312,9 @@
             $status = true;
             break;
         default:
-            echo "action (".$log->module."-".$log->action.") unknow. Not restored<br>";                 //Debug
+            if (!defined('RESTORE_SILENTLY')) {
+                echo "action (".$log->module."-".$log->action.") unknown. Not restored<br />";                 //Debug
+            }
             break;
         }
 
@@ -420,4 +323,42 @@
         }
         return $status;
     }   
+
+    function resource_restore_files($oldid,$newid,$resource,$restore) {
+        global $CFG;
+
+        $status = true;
+        $status = check_dir_exists($CFG->dataroot."/".$restore->course_id,true);
+
+        // we need to do anything referenced by $resource->reference and anything in moddata/resource/instance
+
+        // do referenced files/dirs first.
+        $temp_path = $CFG->dataroot."/temp/backup/".$restore->backup_unique_code.'/course_files/'.$resource->reference;
+        if (file_exists($temp_path)) { // ok, it was backed up, restore it.
+            $new_path = $CFG->dataroot.'/'.$restore->course_id.'/'.$resource->reference;
+        
+            // if this is somewhere deeply nested we need to do all the structure stuff first.....
+            $bits = explode('/',$resource->reference);
+            $newbit = '';
+            for ($i = 0; $i< count($bits)-1; $i++) {
+                $newbit .= $bits[$i].'/';
+                $status = $status && check_dir_exists($CFG->dataroot.'/'.$restore->course_id.'/'.$newbit,true);
+            }
+            $status = $status && backup_copy_file($temp_path,$new_path);
+        }
+
+        // and now for moddata.
+        $temp_path = $CFG->dataroot."/temp/backup/".$restore->backup_unique_code.
+            "/moddata/resource/".$oldid;
+        if (file_exists($temp_path)) { // there's something to back up, restore it.
+            $new_path = $CFG->dataroot."/".$restore->course_id."/".$CFG->moddata;
+            $status = $status && check_dir_exists($new_path,true);
+            $new_path .= '/resource';
+            $status = $status && check_dir_exists($new_path,true);
+            $new_path .= '/'.$newid;
+            $status = $status && backup_copy_file($temp_path,$new_path);
+        }
+        return $status;
+    }
+
 ?>
