@@ -10,11 +10,16 @@ CREATE TABLE prefix_scorm (
   version varchar(9) NOT NULL default '',
   maxgrade float(3) NOT NULL default '0',
   grademethod tinyint(2) NOT NULL default '0',
+  maxattempt int(10) NOT NULL default '1',
   launch int(10) unsigned NOT NULL default '0',
-  summary text NOT NULL,
-  browsemode tinyint(2) NOT NULL default '0',
+  summary text NOT NULL default '',
+  hidebrowse tinyint(1) NOT NULL default '0',
+  hidetoc tinyint(1) NOT NULL default '0',
+  hidenav tinyint(1) NOT NULL default '0',
   auto tinyint(1) unsigned NOT NULL default '0',
-  width int(10) unsigned NOT NULL default '800',
+  popup tinyint(1) unsigned NOT NULL default '0',
+  options varchar(255) NOT NULL default '',
+  width int(10) unsigned NOT NULL default '100',
   height int(10) unsigned NOT NULL default '600',
   timemodified int(10) unsigned NOT NULL default '0',
   PRIMARY KEY  (id),
@@ -50,6 +55,7 @@ CREATE TABLE prefix_scorm_scoes_track (
   userid int(10) unsigned NOT NULL default '0',
   scormid int(10) NOT NULL default '0',
   scoid int(10) unsigned NOT NULL default '0',
+  attempt int(10) unsigned NOT NULL default '1',
   element varchar(255) NOT NULL default '',
   value longtext NOT NULL default '',
   timemodified int(10) unsigned NOT NULL default '0',
@@ -57,15 +63,15 @@ CREATE TABLE prefix_scorm_scoes_track (
   KEY userid (userid),
   KEY scormid (scormid),
   KEY scoid (scoid),
-  KEY elemeny (element),
-  UNIQUE track (userid, scormid, scoid, element)
+  KEY element (element),
+  UNIQUE track (userid, scormid, scoid, attempt, element)
 ) TYPE=MyISAM;
 
 #
 # Dumping data for table log_display
 #
 
-INSERT INTO prefix_log_display VALUES ('scorm', 'view', 'scorm', 'name');
-INSERT INTO prefix_log_display VALUES ('scorm', 'review', 'scorm', 'name');
-INSERT INTO prefix_log_display VALUES ('scorm', 'update', 'scorm', 'name');
-INSERT INTO prefix_log_display VALUES ('scorm', 'add', 'scorm', 'name');
+INSERT INTO prefix_log_display (module, action, mtable, field) VALUES ('scorm', 'view', 'scorm', 'name');
+INSERT INTO prefix_log_display (module, action, mtable, field) VALUES ('scorm', 'review', 'scorm', 'name');
+INSERT INTO prefix_log_display (module, action, mtable, field) VALUES ('scorm', 'update', 'scorm', 'name');
+INSERT INTO prefix_log_display (module, action, mtable, field) VALUES ('scorm', 'add', 'scorm', 'name');
