@@ -1,4 +1,4 @@
-<?php //$Id: restorelib.php,v 1.9.2.2 2005/07/12 07:53:02 moodler Exp $
+<?php //$Id: restorelib.php,v 1.16 2006/04/11 16:19:18 stronk7 Exp $
     //This php script contains all the stuff to backup/restore
     //survey mods
 
@@ -53,7 +53,9 @@
             $newid = insert_record ("survey",$survey);
 
             //Do some output
-            echo "<li>".get_string("modulename","survey")." \"".format_string(stripslashes($survey->name),true)."\"</li>";
+            if (!defined('RESTORE_SILENTLY')) {
+                echo "<li>".get_string("modulename","survey")." \"".format_string(stripslashes($survey->name),true)."\"</li>";
+            }
             backup_flush(300);
 
             if ($newid) {
@@ -61,7 +63,7 @@
                 backup_putid($restore->backup_unique_code,$mod->modtype,
                              $mod->id, $newid);
                 //Now check if want to restore user data and do it.
-                if ($restore->mods['survey']->userinfo) {
+                if (restore_userdata_selected($restore,'survey',$mod->id)) {
                     //Restore survey_answers
                     $status = survey_answers_restore_mods ($newid,$info,$restore);
                     //Restore survey_analysis
@@ -119,9 +121,11 @@
 
             //Do some output
             if (($i+1) % 50 == 0) {
-                echo ".";
-                if (($i+1) % 1000 == 0) {
-                    echo "<br />";
+                if (!defined('RESTORE_SILENTLY')) {
+                    echo ".";
+                    if (($i+1) % 1000 == 0) {
+                        echo "<br />";
+                    }
                 }
                 backup_flush(300);
             }
@@ -175,9 +179,11 @@
 
             //Do some output
             if (($i+1) % 50 == 0) {
-                echo ".";       
-                if (($i+1) % 1000 == 0) {
-                    echo "<br />";
+                if (!defined('RESTORE_SILENTLY')) {
+                    echo ".";       
+                    if (($i+1) % 1000 == 0) {
+                        echo "<br />";
+                    }
                 }
                 backup_flush(300);
             }
@@ -281,17 +287,21 @@
                     $survey->intro = addslashes($result);
                     $status = update_record("survey",$survey);
                     if ($CFG->debug>7) {
-                        echo '<br /><hr />'.htmlentities($content).'<br />changed to<br />'.htmlentities($result).'<hr /><br />';
+                        if (!defined('RESTORE_SILENTLY')) {
+                            echo '<br /><hr />'.s($content).'<br />changed to<br />'.s($result).'<hr /><br />';
+                        }
                     }
                 }
                 //Do some output
                 if (($i+1) % 5 == 0) {
-                    echo ".";
-                    if (($i+1) % 100 == 0) {
-                        echo "<br />";
+                    if (!defined('RESTORE_SILENTLY')) {
+                        echo ".";
+                        if (($i+1) % 100 == 0) {
+                            echo "<br />";
+                        }
                     }
                     backup_flush(300);
-                    }
+                }
             }
         }
 
@@ -383,14 +393,16 @@
                 if ($mod) {
                     //Rebuild the url, extracting the type (txt, xls)
                     $filetype = substr($log->url,-3);
-                    $log->url = "download.php?id=".$log->cmid."&amp;type=".$filetype;
+                    $log->url = "download.php?id=".$log->cmid."&type=".$filetype;
                     $log->info = $mod->new_id;
                     $status = true;
                 }
             }
             break;
         default:
-            echo "action (".$log->module."-".$log->action.") unknow. Not restored<br />";                 //Debug
+            if (!defined('RESTORE_SILENTLY')) {
+                echo "action (".$log->module."-".$log->action.") unknown. Not restored<br />";                 //Debug
+            }
             break;
         }
 
