@@ -1,4 +1,4 @@
-<?php  // $Id: view.php,v 1.45.2.1 2005/10/15 10:37:01 stronk7 Exp $
+<?php  // $Id: view.php,v 1.48.2.1 2006/08/10 15:30:55 skodak Exp $
 
 /*************************************************
     ACTIONS handled are:
@@ -17,15 +17,16 @@
     require("lib.php");
     require("locallib.php");
 
-    require_variable($id);    // Course Module ID
-    optional_variable($action, '');
-    optional_variable($sort, "lastname");
-    optional_variable($dir, "ASC");
+    $id     = required_param('id', PARAM_INT);    // Course Module ID
+    $action = optional_param('action', '', PARAM_ALPHA);
+    $sort   = optional_param('sort', 'lastname', PARAM_ALPHA);
+    $dir    = optional_param('dir', 'ASC', PARAM_ALPHA);
+    $group  = optional_param('group', -1, PARAM_INT);
 
     $timenow = time();
 
     // get some useful stuff...
-    if (! $cm = get_record("course_modules", "id", $id)) {
+    if (! $cm = get_coursemodule_from_id('workshop', $id)) {
         error("Course Module ID was incorrect");
     }
     if (! $course = get_record("course", "id", $cm->course)) {
@@ -303,7 +304,8 @@
 
         /// Check to see if groups are being used in this workshop
         /// and if so, set $currentgroup to reflect the current group
-        $changegroup = isset($_GET['group']) ? $_GET['group'] : -1;  // Group change requested?
+        // $changegroup = isset($_GET['_param('group',0,PARAM_INT);group']) ? $_GET['group'] : -1;  // Group change requested?
+        $changegroup = $group;
         $groupmode = groupmode($course, $cm);   // Groups are being used?
         $currentgroup = get_and_set_current_group($course, $groupmode, $changegroup);
 
