@@ -1,4 +1,4 @@
-<?php  // $Id: format.php,v 1.2 2006/03/01 07:36:09 gustav_delius Exp $ 
+<?php  // $Id: format.php,v 1.2.2.1 2006/08/17 17:37:54 tjhunt Exp $ 
 
 ////////////////////////////////////////////////////////////////////////////
 /// MULTIANSWER FORMAT
@@ -16,14 +16,14 @@ class qformat_multianswer extends qformat_default {
     }
 
     function readquestions($lines) {
-    /// Parses an array of lines into an array of questions.
-    /// For this class the method has been simplified as
-    /// there can never be more than one question for a
-    /// multianswer import
+        // Parses an array of lines into an array of questions.
+        // For this class the method has been simplified as
+        // there can never be more than one question for a
+        // multianswer import
 
         $questions= array();
-        $thequestion= quiz_qtype_multianswer_extract_question
-                            (addslashes(implode('',$lines)));
+        $thequestion= qtype_multianswer_extract_question(
+                addslashes(implode('',$lines)));
         $thequestion->qtype = MULTIANSWER;
         $thequestion->course = $this->course;
 
