@@ -1,4 +1,4 @@
-<?PHP /*  $Id: styles.php,v 1.1.2.1 2005/06/09 08:28:27 moodler Exp $ */
+<?PHP /*  $Id: styles.php,v 1.5 2006/04/07 15:07:55 moodler Exp $ */
 
 /// Every theme should contain a copy of this script.  It lets us 
 /// set up variables and so on before we include the raw CSS files.
@@ -13,6 +13,6 @@
     $themename = basename(dirname(__FILE__));           // Name of the folder we are in
     $forceconfig = optional_param('forceconfig', '', PARAM_FILE);   // Get config from this theme
 
-    style_sheet_setup(filemtime('styles.php'), $lifetime, $themename, $forceconfig);
+    style_sheet_setup(time(), $lifetime, $themename, $forceconfig);
    
 ?>
